@@ -14,7 +14,7 @@
 #'         diagnostic column reporting how many assumptions are
 #'         not respected for a given model.
 #' @export
-#' @examples
+#' @examplesIf requireNamespace("lmtest", quietly = TRUE)
 #' # Create a regression model (using data available in R by default)
 #' model <- lm(mpg ~ wt * cyl + gear, data = mtcars)
 #' nice_assumptions(model)
@@ -61,12 +61,15 @@ nice_assumptions <- function(model) {
   names(df) <- c("Model", "shapiro", "bp", "dw")
   df <- df %>%
     dplyr::mutate(dplyr::across(where(is.numeric), round, 3),
-           Diagnostic = rowSums(dplyr::select(., shapiro:dw) < .05))
+      Diagnostic = rowSums(dplyr::select(., shapiro:dw) < .05)
+    )
 
-  names(df) <- c("Model", "Normality (Shapiro-Wilk)",
-                 "Homoscedasticity (Breusch-Pagan)",
-                 "Autocorrelation of residuals (Durbin-Watson)",
-                 "Diagnostic")
+  names(df) <- c(
+    "Model", "Normality (Shapiro-Wilk)",
+    "Homoscedasticity (Breusch-Pagan)",
+    "Autocorrelation of residuals (Durbin-Watson)",
+    "Diagnostic"
+  )
 
   row.names(df) <- NULL
   class(df) <- c("nice_assumptions", class(df))
