@@ -17,7 +17,7 @@
 #'         (dR), and the lower and upper 95% confidence intervals of the
 #'         effect size (i.e., dR).
 #' @export
-#' @examples
+#' @examplesIf requireNamespace("bootES", quietly = TRUE) && requireNamespace("emmeans", quietly = TRUE)
 #' # Basic example
 #' nice_contrasts(
 #'   data = mtcars,
@@ -108,8 +108,8 @@ nice_contrasts <- function(response,
   boot.sums <- lapply(seq(length(response)), function(y) {
     lapply(es.lists, function(x) {
       as.data.frame(summary(x[[y]]))
-        }) %>%
-      bind_rows
+    }) %>%
+      bind_rows()
   })
   list.names <- c("estimates", "SE", "df", "tratio", "pvalue")
   stats.list <- list()
@@ -148,7 +148,8 @@ nice_contrasts <- function(response,
     effect.type == "hedges.g" ~ "g",
     effect.type == "cohens.d.sigma" ~ "d_sigma",
     effect.type == "r" ~ "r",
-    effect.type == "akp.robust.d" ~ "dR")
+    effect.type == "akp.robust.d" ~ "dR"
+  )
 
   names(table.stats) <- c(
     "Dependent Variable", "Comparison", "df",
